@@ -138,7 +138,7 @@ SoundManager::intern_create_sound_source(const std::string& filename)
       auto stream_source = std::make_unique<StreamSoundSource>();
       stream_source->set_sound_file(std::move(file));
       stream_source->set_volume(static_cast<float>(m_sound_volume) / 100.0f);
-      return std::move(stream_source);
+      return std::unique_ptr<OpenALSoundSource>(stream_source.release());
     }
   }
 
@@ -291,8 +291,8 @@ SoundManager::set_music_volume(int volume)
   if (m_music_source != nullptr) m_music_source->set_volume(static_cast<float>(volume) / 100.0f);
 }
 
-void
-SoundManager::play_music(const std::string& filename, bool fade)
+void 
+SoundManager::play_music(const std::string& filename, float fadetime)
 {
   if (filename == m_current_music && m_music_source != nullptr)
   {
@@ -321,8 +321,8 @@ SoundManager::play_music(const std::string& filename, bool fade)
     newmusic->set_looping(true);
     newmusic->set_relative(true);
     newmusic->set_volume(static_cast<float>(m_music_volume) / 100.0f);
-    if (fade)
-      newmusic->set_fading(StreamSoundSource::FadingOn, .5f);
+    if (fadetime > 0)
+      newmusic->set_fading(StreamSoundSource::FadingOn, fadetime);
     newmusic->play();
 
     m_music_source = std::move(newmusic);
@@ -333,6 +333,12 @@ SoundManager::play_music(const std::string& filename, bool fade)
   }
 }
 
+void
+SoundManager::play_music(const std::string& filename, bool fade)
+{
+  play_music(filename, fade ? 0.5f : 0);
+}
+
 void
 SoundManager::pause_music(float fadetime)
 {
