@@ -50,6 +50,7 @@ BadGuy::BadGuy(const Vector& pos, const std::string& sprite_name_, int layer_,
 BadGuy::BadGuy(const Vector& pos, Direction direction, const std::string& sprite_name_, int layer_,
                const std::string& light_sprite_name) :
   MovingSprite(pos, sprite_name_, layer_, COLGROUP_DISABLED),
+  ExposedObject<BadGuy, scripting::BadGuy>(this),
   m_physic(),
   m_countMe(true),
   m_is_initialized(false),
@@ -83,6 +84,7 @@ BadGuy::BadGuy(const Vector& pos, Direction direction, const std::string& sprite
 BadGuy::BadGuy(const ReaderMapping& reader, const std::string& sprite_name_, int layer_,
                const std::string& light_sprite_name) :
   MovingSprite(reader, sprite_name_, layer_, COLGROUP_DISABLED),
+  ExposedObject<BadGuy, scripting::BadGuy>(this),
   m_physic(),
   m_countMe(true),
   m_is_initialized(false),
@@ -599,20 +601,25 @@ BadGuy::set_state(State state_)
 bool
 BadGuy::is_offscreen() const
 {
-  Vector dist;
+  Vector cam_dist;
+  Vector player_dist;
+  Camera& cam = Sector::get().get_camera();
+  cam_dist = cam.get_center() - m_col.m_bbox.get_middle();
   if (Editor::is_active()) {
-    Camera& cam = Sector::get().get_camera();
-    dist = cam.get_center() - m_col.m_bbox.get_middle();
+      if ((fabsf(cam_dist.x) <= X_OFFSCREEN_DISTANCE) && (fabsf(cam_dist.y) <= Y_OFFSCREEN_DISTANCE)) {
+        return false;
+    }
   }
   auto player = get_nearest_player();
   if (!player)
     return false;
   if (!Editor::is_active()) {
-    dist = player->get_bbox().get_middle() - m_col.m_bbox.get_middle();
+    player_dist = player->get_bbox().get_middle() - m_col.m_bbox.get_middle();
   }
   // In SuperTux 0.1.x, Badguys were activated when Tux<->Badguy center distance was approx. <= ~668px
   // This doesn't work for wide-screen monitors which give us a virt. res. of approx. 1066px x 600px
-  if ((fabsf(dist.x) <= X_OFFSCREEN_DISTANCE) && (fabsf(dist.y) <= Y_OFFSCREEN_DISTANCE)) {
+  if (((fabsf(player_dist.x) <= X_OFFSCREEN_DISTANCE) && (fabsf(player_dist.y) <= Y_OFFSCREEN_DISTANCE))
+      ||((fabsf(cam_dist.x) <= X_OFFSCREEN_DISTANCE) && (fabsf(cam_dist.y) <= Y_OFFSCREEN_DISTANCE))) {
     return false;
   }
   return true;
@@ -898,4 +905,24 @@ BadGuy::after_editor_set()
   }
 }
 
+bool
+BadGuy::can_be_affected_by_wind() const
+{
+  return !on_ground();
+}
+
+void
+BadGuy::add_wind_velocity(const Vector& velocity, const Vector& end_speed)
+{
+  // only add velocity in the same direction as the wind
+  if (end_speed.x > 0 && m_physic.get_velocity_x() < end_speed.x)
+    m_physic.set_velocity_x(std::min(m_physic.get_velocity_x() + velocity.x, end_speed.x));
+  if (end_speed.x < 0 && m_physic.get_velocity_x() > end_speed.x)
+    m_physic.set_velocity_x(std::max(m_physic.get_velocity_x() + velocity.x, end_speed.x));
+  if (end_speed.y > 0 && m_physic.get_velocity_y() < end_speed.y)
+    m_physic.set_velocity_y(std::min(m_physic.get_velocity_y() + velocity.y, end_speed.y));
+  if (end_speed.y < 0 && m_physic.get_velocity_y() > end_speed.y)
+    m_physic.set_velocity_y(std::max(m_physic.get_velocity_y() + velocity.y, end_speed.y));
+}
+
 /* EOF */
