@@ -21,6 +21,7 @@
 #include "audio/sound_manager.hpp"
 #include "object/player.hpp"
 #include "sprite/sprite.hpp"
+#include "supertux/sector.hpp"
 
 namespace {
 const float KICKSPEED = 500;
@@ -191,6 +192,9 @@ MrIceBlock::collision_squished(GameObject& object)
         }
       }
 
+      SoundManager::current()->play("sounds/stomp.wav", get_pos());
+      m_physic.set_velocity_x(0);
+      m_physic.set_velocity_y(0);
       set_state(ICESTATE_FLAT);
       nokick_timer.start(NOKICK_TIME);
       break;
@@ -218,7 +222,7 @@ MrIceBlock::collision_squished(GameObject& object)
 }
 
 void
-MrIceBlock::set_state(IceState state_, bool up)
+MrIceBlock::set_state(IceState state_)
 {
   if (ice_state == state_)
     return;
@@ -229,13 +233,6 @@ MrIceBlock::set_state(IceState state_, bool up)
       WalkingBadguy::initialize();
       break;
     case ICESTATE_FLAT:
-      if (up) {
-        m_physic.set_velocity_y(-KICKSPEED);
-      } else {
-        SoundManager::current()->play("sounds/stomp.wav", get_pos());
-        m_physic.set_velocity_x(0);
-        m_physic.set_velocity_y(0);
-      }
       set_action(m_dir == Direction::LEFT ? "flat-left" : "flat-right", /* loops = */ -1);
       flat_timer.start(4);
       break;
@@ -275,7 +272,16 @@ void
 MrIceBlock::ungrab(MovingObject& object, Direction dir_)
 {
   if (dir_ == Direction::UP) {
-    set_state(ICESTATE_FLAT, true);
+    m_physic.set_velocity_y(-KICKSPEED);
+    set_state(ICESTATE_FLAT);
+  } else if (dir_ == Direction::DOWN) {
+    Vector mov(0, 32);
+    if (Sector::get().is_free_of_statics(get_bbox().moved(mov), this)) {
+      // There is free space, so throw it down
+      SoundManager::current()->play("sounds/kick.wav", get_pos());
+      m_physic.set_velocity_y(KICKSPEED);
+    }
+    set_state(ICESTATE_FLAT);
   } else {
     m_dir = dir_;
     set_state(ICESTATE_KICKED);
