@@ -24,10 +24,10 @@ class PoisonIvy final : public WalkingBadguy
 public:
   PoisonIvy(const ReaderMapping& reader);
   PoisonIvy(const Vector& pos, Direction d);
-
+  
   virtual bool is_freezable() const override;
   virtual std::string get_class() const override { return "poisonivy"; }
-  virtual std::string get_display_name() const override { return _("Poisonous ivy"); }
+  virtual std::string get_display_name() const override { return _("Spring Leaf"); }
 
 protected:
   virtual bool collision_squished(GameObject& object) override;
