@@ -26,7 +26,7 @@ public:
 
   virtual std::string get_water_sprite() const override { return "images/objects/water_drop/pink_drop.sprite"; }
   virtual std::string get_class() const override { return "smartblock"; }
-  virtual std::string get_display_name() const override { return _("Smart Block"); }
+  virtual std::string get_display_name() const override { return _("Smartblock"); }
 
 private:
   SmartBlock(const SmartBlock&) = delete;
