@@ -61,11 +61,34 @@ CollisionSystem::remove(CollisionObject* object)
 void
 CollisionSystem::draw(DrawingContext& context)
 {
-  const Color color(1.0f, 0.0f, 0.0f, 0.75f);
-
+  const Color violet(0.5f, 0.0f, 1.0f, 0.75f);
+  const Color red(1.0f, 0.0f, 0.0f, 0.75f);
+  const Color red_bright(1.0f, 0.5f, 0.5f, 0.75f);
+  const Color cyan(0.0f, 1.0f, 1.0f, 0.75f);
+  const Color orange(1.0f, 0.5f, 0.0f, 0.75f);
+  const Color green_bright(0.7f, 1.0f, 0.7f, 0.75f);
   for (auto& object : m_objects) {
+    Color color;
+    switch (object->get_group()) {
+    case COLGROUP_MOVING_STATIC:
+      color = violet;
+      break;
+    case COLGROUP_MOVING:
+      color = red;
+      break;
+    case COLGROUP_MOVING_ONLY_STATIC:
+      color = red_bright;
+      break;
+    case COLGROUP_STATIC:
+      color = cyan;
+      break;
+    case COLGROUP_TOUCHABLE:
+      color = orange;
+      break;
+    default:
+      color = green_bright;
+    }
     const Rectf& rect = object->get_bbox();
-
     context.color().draw_filled_rect(rect, color, LAYER_FOREGROUND1 + 10);
   }
 }
@@ -645,8 +668,8 @@ CollisionSystem::free_line_of_sight(const Vector& line_start, const Vector& line
   const float lsy = std::min(line_start.y, line_end.y);
   const float ley = std::max(line_start.y, line_end.y);
 
-  for (float test_x = lsx; test_x <= lex; test_x += 16) {
-    for (float test_y = lsy; test_y <= ley; test_y += 16) {
+  for (float test_x = lsx; test_x <= lex; test_x += 16) { // NOLINT
+    for (float test_y = lsy; test_y <= ley; test_y += 16) { // NOLINT
       for (const auto& solids : m_sector.get_solid_tilemaps()) {
         const Tile& tile = solids->get_tile_at(Vector(test_x, test_y));
         // FIXME: check collision with slope tiles
