@@ -95,7 +95,7 @@ Editor::Editor() :
   m_toolbox_widget(),
   m_layers_widget(),
   m_enabled(false),
-  m_bgr_surface(Surface::from_file("images/background/arctis2.png")),
+  m_bgr_surface(Surface::from_file("images/background/antarctic/arctis2.png")),
   m_undo_manager(new UndoManager),
   m_ignore_sector_change(false)
 {
@@ -106,12 +106,10 @@ Editor::Editor() :
   m_toolbox_widget = toolbox_widget.get();
   m_layers_widget = layers_widget.get();
   m_overlay_widget = overlay_widget.get();
-  
-  auto undo_button_widget = std::make_unique<ButtonWidget>(
-    SpriteManager::current()->create("images/engine/editor/undo.png"),
+
+  auto undo_button_widget = std::make_unique<ButtonWidget>("images/engine/editor/undo.png",
     Vector(10, 10), [this]{ undo(); });
-  auto redo_button_widget = std::make_unique<ButtonWidget>(
-    SpriteManager::current()->create("images/engine/editor/redo.png"),
+  auto redo_button_widget = std::make_unique<ButtonWidget>("images/engine/editor/redo.png",
     Vector(60, 10), [this]{ redo(); });
 
   m_widgets.push_back(std::move(undo_button_widget));
@@ -131,22 +129,20 @@ Editor::draw(Compositor& compositor)
   auto& context = compositor.make_context();
 
   if (m_levelloaded) {
+  for(const auto& widget : m_widgets) {
+    widget->draw(context);
+  }
+
     m_sector->draw(context);
-    context.color().draw_filled_rect(Rectf(Vector(0, 0), Vector(static_cast<float>(context.get_width()),
-                                                                static_cast<float>(context.get_height()))),
+    context.color().draw_filled_rect(context.get_rect(),
                                      Color(0.0f, 0.0f, 0.0f),
                                      0.0f, std::numeric_limits<int>::min());
   } else {
     context.color().draw_surface_scaled(m_bgr_surface,
-                                        Rectf(Vector(0, 0), Vector(static_cast<float>(context.get_width()),
-                                                                   static_cast<float>(context.get_height()))),
+                                        context.get_rect(),
                                         -100);
   }
 
-  for(const auto& widget : m_widgets) {
-    widget->draw(context);
-  }
-
   MouseCursor::current()->draw(context);
 }
 
@@ -585,25 +581,25 @@ Editor::event(const SDL_Event& ev)
   if (!m_enabled) return;
 
   try
-  {	
+  {
 	if (ev.type == SDL_KEYDOWN &&
         ev.key.keysym.sym == SDLK_t &&
         ev.key.keysym.mod & KMOD_CTRL) {
 		test_level();
 		}
-		
+
 	if (ev.type == SDL_KEYDOWN &&
         ev.key.keysym.sym == SDLK_s &&
         ev.key.keysym.mod & KMOD_CTRL) {
 		save_level();
 		}
-		
+
 	if (ev.type == SDL_KEYDOWN &&
         ev.key.keysym.sym == SDLK_z &&
         ev.key.keysym.mod & KMOD_CTRL) {
 		undo();
 		}
-		
+
 	if (ev.type == SDL_KEYDOWN &&
         ev.key.keysym.sym == SDLK_y &&
         ev.key.keysym.mod & KMOD_CTRL) {
@@ -639,8 +635,9 @@ Editor::event(const SDL_Event& ev)
       }
     }
 
-    // scroll with mouse wheel
-    if (ev.type == SDL_MOUSEWHEEL) {
+    // Scroll with mouse wheel, if the mouse is not over the toolbox.
+    // The toolbox does scrolling independently from the main area.
+    if (ev.type == SDL_MOUSEWHEEL && !m_toolbox_widget->has_mouse_focus()) {
       float scroll_x = static_cast<float>(ev.wheel.x * -32);
       float scroll_y = static_cast<float>(ev.wheel.y * -32);
       scroll({scroll_x, scroll_y});
