@@ -51,15 +51,15 @@ static const float MENU_REPEAT_INITIAL = 0.4f;
 static const float MENU_REPEAT_RATE    = 0.1f;
 
 Menu::Menu() :
-  pos(Vector(static_cast<float>(SCREEN_WIDTH) / 2.0f,
-             static_cast<float>(SCREEN_HEIGHT) / 2.0f)),
-  delete_character(0),
-  mn_input_char('\0'),
-  menu_repeat_time(),
-  menu_width(),
-  items(),
-  arrange_left(0),
-  active_item(-1)
+  m_pos(Vector(static_cast<float>(SCREEN_WIDTH) / 2.0f,
+               static_cast<float>(SCREEN_HEIGHT) / 2.0f)),
+  m_delete_character(0),
+  m_mn_input_char('\0'),
+  m_menu_repeat_time(),
+  m_menu_width(),
+  m_items(),
+  m_arrange_left(0),
+  m_active_item(-1)
 {
 }
 
@@ -70,25 +70,25 @@ Menu::~Menu()
 void
 Menu::set_center_pos(float x, float y)
 {
-  pos.x = x;
-  pos.y = y;
+  m_pos.x = x;
+  m_pos.y = y;
 }
 
 /* Add an item to a menu */
 MenuItem&
 Menu::add_item(std::unique_ptr<MenuItem> new_item)
 {
-  items.push_back(std::move(new_item));
-  MenuItem& item = *items.back();
+  m_items.push_back(std::move(new_item));
+  MenuItem& item = *m_items.back();
 
   /* If a new menu is being built, the active item shouldn't be set to
    * something that isn't selectable. Set the active_item to the first
    * selectable item added.
    */
 
-  if (active_item == -1 && !item.skippable())
+  if (m_active_item == -1 && !item.skippable())
   {
-    active_item = static_cast<int>(items.size()) - 1;
+    m_active_item = static_cast<int>(m_items.size()) - 1;
   }
 
   calculate_width();
@@ -99,16 +99,15 @@ Menu::add_item(std::unique_ptr<MenuItem> new_item)
 MenuItem&
 Menu::add_item(std::unique_ptr<MenuItem> new_item, int pos_)
 {
-  items.insert(items.begin()+pos_,std::move(new_item));
-  MenuItem& item = *items[pos_];
+  m_items.insert(m_items.begin()+pos_,std::move(new_item));
+  MenuItem& item = *m_items[pos_];
 
-  /* When the item is inserted before the selected item, the
-   * same menu item should be still selected.
-   */
+  // When the item is inserted before the selected item, the
+  // same menu item should be still selected.
 
-  if (active_item >= pos_)
+  if (m_active_item >= pos_)
   {
-    active_item++;
+    m_active_item++;
   }
 
   calculate_width();
@@ -119,20 +118,19 @@ Menu::add_item(std::unique_ptr<MenuItem> new_item, int pos_)
 void
 Menu::delete_item(int pos_)
 {
-  items.erase(items.begin()+pos_);
+  m_items.erase(m_items.begin()+pos_);
 
-  /* When the item is deleted before the selected item, the
-   * same menu item should be still selected.
-   */
+  // When the item is deleted before the selected item, the
+  // same menu item should be still selected.
 
-  if (active_item >= pos_)
+  if (m_active_item >= pos_)
   {
     do {
-      if (active_item > 0)
-        --active_item;
+      if (m_active_item > 0)
+        --m_active_item;
       else
-        active_item = int(items.size())-1;
-    } while (items[active_item]->skippable());
+        m_active_item = int(m_items.size())-1;
+    } while (m_items[m_active_item]->skippable());
   }
 }
 
@@ -294,8 +292,8 @@ Menu::add_submenu(const std::string& text, int submenu, int id)
 }
 
 ItemColorChannel&
-Menu::add_color_channel(float* input, Color channel, int id) {
-  auto item = std::make_unique<ItemColorChannel>(input, channel, id);
+Menu::add_color_channel(float* input, Color channel, int id, bool is_linear) {
+  auto item = std::make_unique<ItemColorChannel>(input, channel, id, is_linear);
   auto item_ptr = item.get();
   add_item(std::move(item));
   return *item_ptr;
@@ -328,87 +326,129 @@ Menu::add_badguy_select(const std::string& text, std::vector<std::string>* badgu
 void
 Menu::clear()
 {
-  items.clear();
-  active_item = -1;
+  m_items.clear();
+  m_active_item = -1;
 }
 
 void
 Menu::process_input(const Controller& controller)
 {
-  int menu_height = static_cast<int>(get_height());
-  if (menu_height > SCREEN_HEIGHT)
   { // Scrolling
-    int scroll_offset = (menu_height - SCREEN_HEIGHT) / 2 + 32;
-    pos.y = static_cast<float>(SCREEN_HEIGHT) / 2.0f - static_cast<float>(scroll_offset) * ((static_cast<float>(active_item) / static_cast<float>(items.size() - 1)) - 0.5f) * 2.0f;
+
+    // If a help text is present, make some space at the bottom of the
+    // menu so that the last few items don't overlap with the help
+    // text.
+    float help_height = 0.0f;
+    for (auto& item : m_items) {
+      if (!item->get_help().empty()) {
+        help_height = 96.0f;
+        break;
+      }
+    }
+
+    // Find the first and last selectable item in the current menu, so
+    // that the top most selected item gives a scroll_pos of -1.0f and
+    // the bottom most gives 1.0f, as otherwise the non-selectable
+    // header would be cut off.
+    size_t first_idx = m_items.size();
+    size_t last_idx = m_items.size();
+    for (size_t i = 0; i < m_items.size(); ++i) {
+      if (!m_items[i]->skippable()) {
+        if (first_idx == m_items.size()) {
+          first_idx = i;
+        }
+        last_idx = i;
+      }
+    }
+
+    const float screen_height = static_cast<float>(SCREEN_HEIGHT);
+    const float menu_area = screen_height - help_height;
+    // get_height() doesn't include the border, so we manually add some
+    const float menu_height = get_height() + 32.0f;
+    const float center_y = menu_area / 2.0f;
+    if (menu_height > menu_area)
+    {
+      const float scroll_range = (menu_height - menu_area) / 2.0f;
+      const float scroll_pos = ((static_cast<float>(m_active_item - first_idx)
+                                 / static_cast<float>(last_idx - first_idx)) - 0.5f) * 2.0f;
+
+      m_pos.y = floorf(center_y - scroll_range * scroll_pos);
+    }
+    else
+    {
+      if (help_height != 0.0f) {
+        m_pos.y = floorf(center_y);
+      }
+    }
   }
 
   MenuAction menuaction = MenuAction::NONE;
 
   /** check main input controller... */
-  if (controller.pressed(Controller::UP)) {
+  if (controller.pressed(Control::UP)) {
     menuaction = MenuAction::UP;
-    menu_repeat_time = g_real_time + MENU_REPEAT_INITIAL;
+    m_menu_repeat_time = g_real_time + MENU_REPEAT_INITIAL;
   }
-  if (controller.hold(Controller::UP) &&
-     menu_repeat_time != 0 && g_real_time > menu_repeat_time) {
+  if (controller.hold(Control::UP) &&
+     m_menu_repeat_time != 0 && g_real_time > m_menu_repeat_time) {
     menuaction = MenuAction::UP;
-    menu_repeat_time = g_real_time + MENU_REPEAT_RATE;
+    m_menu_repeat_time = g_real_time + MENU_REPEAT_RATE;
   }
 
-  if (controller.pressed(Controller::DOWN)) {
+  if (controller.pressed(Control::DOWN)) {
     menuaction = MenuAction::DOWN;
-    menu_repeat_time = g_real_time + MENU_REPEAT_INITIAL;
+    m_menu_repeat_time = g_real_time + MENU_REPEAT_INITIAL;
   }
-  if (controller.hold(Controller::DOWN) &&
-     menu_repeat_time != 0 && g_real_time > menu_repeat_time) {
+  if (controller.hold(Control::DOWN) &&
+     m_menu_repeat_time != 0 && g_real_time > m_menu_repeat_time) {
     menuaction = MenuAction::DOWN;
-    menu_repeat_time = g_real_time + MENU_REPEAT_RATE;
+    m_menu_repeat_time = g_real_time + MENU_REPEAT_RATE;
   }
 
-  if (controller.pressed(Controller::LEFT)) {
+  if (controller.pressed(Control::LEFT)) {
     menuaction = MenuAction::LEFT;
-    menu_repeat_time = g_real_time + MENU_REPEAT_INITIAL;
+    m_menu_repeat_time = g_real_time + MENU_REPEAT_INITIAL;
   }
-  if (controller.hold(Controller::LEFT) &&
-     menu_repeat_time != 0 && g_real_time > menu_repeat_time) {
+  if (controller.hold(Control::LEFT) &&
+     m_menu_repeat_time != 0 && g_real_time > m_menu_repeat_time) {
     menuaction = MenuAction::LEFT;
-    menu_repeat_time = g_real_time + MENU_REPEAT_RATE;
+    m_menu_repeat_time = g_real_time + MENU_REPEAT_RATE;
   }
 
-  if (controller.pressed(Controller::RIGHT)) {
+  if (controller.pressed(Control::RIGHT)) {
     menuaction = MenuAction::RIGHT;
-    menu_repeat_time = g_real_time + MENU_REPEAT_INITIAL;
+    m_menu_repeat_time = g_real_time + MENU_REPEAT_INITIAL;
   }
-  if (controller.hold(Controller::RIGHT) &&
-     menu_repeat_time != 0 && g_real_time > menu_repeat_time) {
+  if (controller.hold(Control::RIGHT) &&
+     m_menu_repeat_time != 0 && g_real_time > m_menu_repeat_time) {
     menuaction = MenuAction::RIGHT;
-    menu_repeat_time = g_real_time + MENU_REPEAT_RATE;
+    m_menu_repeat_time = g_real_time + MENU_REPEAT_RATE;
   }
 
-  if (controller.pressed(Controller::ACTION) ||
-     controller.pressed(Controller::MENU_SELECT) ||
-     (!is_sensitive() && controller.pressed(Controller::MENU_SELECT_SPACE))) {
+  if (controller.pressed(Control::ACTION) ||
+     controller.pressed(Control::MENU_SELECT) ||
+     (!is_sensitive() && controller.pressed(Control::MENU_SELECT_SPACE))) {
     menuaction = MenuAction::HIT;
   }
 
-  if (controller.pressed(Controller::ESCAPE) ||
-     controller.pressed(Controller::CHEAT_MENU) ||
-     controller.pressed(Controller::DEBUG_MENU) ||
-     controller.pressed(Controller::MENU_BACK)) {
+  if (controller.pressed(Control::ESCAPE) ||
+     controller.pressed(Control::CHEAT_MENU) ||
+     controller.pressed(Control::DEBUG_MENU) ||
+     controller.pressed(Control::MENU_BACK)) {
     menuaction = MenuAction::BACK;
   }
 
-  if (controller.pressed(Controller::REMOVE)) {
+  if (controller.pressed(Control::REMOVE)) {
     menuaction = MenuAction::REMOVE;
-    menu_repeat_time = g_real_time + MENU_REPEAT_INITIAL;
+    m_menu_repeat_time = g_real_time + MENU_REPEAT_INITIAL;
   }
-  if (controller.hold(Controller::REMOVE) &&
-     menu_repeat_time != 0 && g_real_time > menu_repeat_time) {
+  if (controller.hold(Control::REMOVE) &&
+     m_menu_repeat_time != 0 && g_real_time > m_menu_repeat_time) {
     menuaction = MenuAction::REMOVE;
-    menu_repeat_time = g_real_time + MENU_REPEAT_RATE;
+    m_menu_repeat_time = g_real_time + MENU_REPEAT_RATE;
   }
 
-  if (items.size() == 0)
+  if (m_items.size() == 0)
     return;
 
   // The menu_action() call can pop() the menu from the stack and thus
@@ -420,27 +460,27 @@ Menu::process_input(const Controller& controller)
 void
 Menu::process_action(const MenuAction& menuaction)
 {
-  int last_active_item = active_item;
+  const int last_active_item = m_active_item;
 
   switch (menuaction) {
     case MenuAction::UP:
       do {
-        if (active_item > 0)
-          --active_item;
+        if (m_active_item > 0)
+          --m_active_item;
         else
-          active_item = int(items.size())-1;
-      } while (items[active_item]->skippable()
-               && (active_item != last_active_item));
+          m_active_item = int(m_items.size())-1;
+      } while (m_items[m_active_item]->skippable()
+               && (m_active_item != last_active_item));
       break;
 
     case MenuAction::DOWN:
       do {
-        if (active_item < int(items.size())-1 )
-          ++active_item;
+        if (m_active_item < int(m_items.size())-1 )
+          ++m_active_item;
         else
-          active_item = 0;
-      } while (items[active_item]->skippable()
-               && (active_item != last_active_item));
+          m_active_item = 0;
+      } while (m_items[m_active_item]->skippable()
+               && (m_active_item != last_active_item));
       break;
 
     case MenuAction::BACK:
@@ -453,46 +493,46 @@ Menu::process_action(const MenuAction& menuaction)
       break;
   }
 
-  if (items[active_item]->no_other_action()) {
-    items[active_item]->process_action(menuaction);
+  if (m_items[m_active_item]->no_other_action()) {
+    m_items[m_active_item]->process_action(menuaction);
     return;
   }
 
-  items[active_item]->process_action(menuaction);
-  if (items[active_item]->changes_width()) {
+  m_items[m_active_item]->process_action(menuaction);
+  if (m_items[m_active_item]->changes_width()) {
     calculate_width();
   }
   if (menuaction == MenuAction::HIT) {
-    menu_action(*items[active_item]);
+    menu_action(*m_items[m_active_item]);
   }
 }
 
 void
 Menu::draw_item(DrawingContext& context, int index)
 {
-  float menu_height = get_height();
-  float menu_width_ = get_width();
+  const float menu_height = get_height();
+  const float menu_width = get_width();
 
-  MenuItem* pitem = items[index].get();
+  MenuItem* pitem = m_items[index].get();
 
-  float x_pos       = pos.x - menu_width_/2;
-  float y_pos       = pos.y + 24.0f * static_cast<float>(index) - menu_height / 2.0f + 12.0f;
+  const float x_pos = m_pos.x - menu_width / 2.0f;
+  const float y_pos = m_pos.y + 24.0f * static_cast<float>(index) - menu_height / 2.0f + 12.0f;
 
-  pitem->draw(context, Vector(x_pos, y_pos), static_cast<int>(menu_width_), active_item == index);
+  pitem->draw(context, Vector(x_pos, y_pos), static_cast<int>(menu_width), m_active_item == index);
 
-  if (active_item == index)
+  if (m_active_item == index)
   {
     float blink = (sinf(g_real_time * math::PI * 1.0f)/2.0f + 0.5f) * 0.5f + 0.25f;
-    context.color().draw_filled_rect(Rectf(Vector(pos.x - menu_width_/2 + 10 - 2, y_pos - 12 - 2),
-                                   Vector(pos.x + menu_width_/2 - 10 + 2, y_pos + 12 + 2)),
-                             Color(1.0f, 1.0f, 1.0f, blink),
-                             14.0f,
-                             LAYER_GUI-10);
-    context.color().draw_filled_rect(Rectf(Vector(pos.x - menu_width_/2 + 10, y_pos - 12),
-                                   Vector(pos.x + menu_width_/2 - 10, y_pos + 12)),
-                             Color(1.0f, 1.0f, 1.0f, 0.5f),
-                             12.0f,
-                             LAYER_GUI-10);
+    context.color().draw_filled_rect(Rectf(Vector(m_pos.x - menu_width/2 + 10 - 2, y_pos - 12 - 2),
+                                           Vector(m_pos.x + menu_width/2 - 10 + 2, y_pos + 12 + 2)),
+                                     Color(1.0f, 1.0f, 1.0f, blink),
+                                     14.0f,
+                                     LAYER_GUI-10);
+    context.color().draw_filled_rect(Rectf(Vector(m_pos.x - menu_width/2 + 10, y_pos - 12),
+                                           Vector(m_pos.x + menu_width/2 - 10, y_pos + 12)),
+                                     Color(1.0f, 1.0f, 1.0f, 0.5f),
+                                     12.0f,
+                                     LAYER_GUI-10);
   }
 }
 
@@ -502,73 +542,73 @@ Menu::calculate_width()
   /* The width of the menu has to be more than the width of the text
      with the most characters */
   float max_width = 0;
-  for (unsigned int i = 0; i < items.size(); ++i)
+  for (unsigned int i = 0; i < m_items.size(); ++i)
   {
-    float w = static_cast<float>(items[i]->get_width());
+    float w = static_cast<float>(m_items[i]->get_width());
     if (w > max_width)
       max_width = w;
   }
-  menu_width = max_width;
+  m_menu_width = max_width;
 }
 
 float
 Menu::get_width() const
 {
-  return menu_width + 24;
+  return m_menu_width + 24;
 }
 
 float
 Menu::get_height() const
 {
-  return static_cast<float>(items.size() * 24);
+  return static_cast<float>(m_items.size() * 24);
 }
 
 void
 Menu::on_window_resize()
 {
-  pos.x = static_cast<float>(SCREEN_WIDTH) / 2.0f;
-  pos.y = static_cast<float>(SCREEN_HEIGHT) / 2.0f;
+  m_pos.x = static_cast<float>(SCREEN_WIDTH) / 2.0f;
+  m_pos.y = static_cast<float>(SCREEN_HEIGHT) / 2.0f;
 }
 
 void
 Menu::draw(DrawingContext& context)
 {
-  if (!items[active_item]->get_help().empty())
-  {
-    int text_width  = static_cast<int>(Resources::normal_font->get_text_width(items[active_item]->get_help()));
-    int text_height = static_cast<int>(Resources::normal_font->get_text_height(items[active_item]->get_help()));
-
-    Rectf text_rect(pos.x - static_cast<float>(text_width) / 2.0f - 8.0f,
-                    static_cast<float>(SCREEN_HEIGHT) - 48.0f - static_cast<float>(text_height) / 2.0f - 4.0f,
-                    pos.x + static_cast<float>(text_width) / 2.0f + 8.0f,
-                    static_cast<float>(SCREEN_HEIGHT) - 48.0f + static_cast<float>(text_height) / 2.0f + 4.0f);
-
-    context.color().draw_filled_rect(Rectf(text_rect.p1() - Vector(4,4),
-                                             text_rect.p2() + Vector(4,4)),
-                                       Color(0.2f, 0.3f, 0.4f, 0.8f),
-                                       16.0f,
-                                       LAYER_GUI-10);
-
-    context.color().draw_filled_rect(text_rect,
-                                       Color(0.6f, 0.7f, 0.8f, 0.5f),
-                                       16.0f,
-                                       LAYER_GUI-10);
-
-    context.color().draw_text(Resources::normal_font, items[active_item]->get_help(),
-                              Vector(pos.x, static_cast<float>(SCREEN_HEIGHT) - 48.0f - static_cast<float>(text_height) / 2.0f),
-                              ALIGN_CENTER, LAYER_GUI);
-  }
-
-  for (unsigned int i = 0; i < items.size(); ++i)
+  for (unsigned int i = 0; i < m_items.size(); ++i)
   {
     draw_item(context, i);
   }
+
+  if (!m_items[m_active_item]->get_help().empty())
+  {
+    const int text_width = static_cast<int>(Resources::normal_font->get_text_width(m_items[m_active_item]->get_help()));
+    const int text_height = static_cast<int>(Resources::normal_font->get_text_height(m_items[m_active_item]->get_help()));
+
+    const Rectf text_rect(m_pos.x - static_cast<float>(text_width) / 2.0f - 8.0f,
+                          static_cast<float>(SCREEN_HEIGHT) - 48.0f - static_cast<float>(text_height) / 2.0f - 4.0f,
+                          m_pos.x + static_cast<float>(text_width) / 2.0f + 8.0f,
+                          static_cast<float>(SCREEN_HEIGHT) - 48.0f + static_cast<float>(text_height) / 2.0f + 4.0f);
+
+    context.color().draw_filled_rect(Rectf(text_rect.p1() - Vector(4,4),
+                                           text_rect.p2() + Vector(4,4)),
+                                     Color(0.5f, 0.6f, 0.7f, 0.8f),
+                                     16.0f,
+                                     LAYER_GUI);
+
+    context.color().draw_filled_rect(text_rect,
+                                     Color(0.8f, 0.9f, 1.0f, 0.5f),
+                                     16.0f,
+                                     LAYER_GUI);
+
+    context.color().draw_text(Resources::normal_font, m_items[m_active_item]->get_help(),
+                              Vector(m_pos.x, static_cast<float>(SCREEN_HEIGHT) - 48.0f - static_cast<float>(text_height) / 2.0f),
+                              ALIGN_CENTER, LAYER_GUI);
+  }
 }
 
 MenuItem&
 Menu::get_item_by_id(int id)
 {
-  for (const auto& item : items)
+  for (const auto& item : m_items)
   {
     if (item->get_id() == id)
     {
@@ -582,7 +622,7 @@ Menu::get_item_by_id(int id)
 const MenuItem&
 Menu::get_item_by_id(int id) const
 {
-  for (const auto& item : items)
+  for (const auto& item : m_items)
   {
     if (item->get_id() == id)
     {
@@ -595,18 +635,19 @@ Menu::get_item_by_id(int id) const
 
 int Menu::get_active_item_id() const
 {
-  return items[active_item]->get_id();
+  return m_items[m_active_item]->get_id();
 }
 
 void
 Menu::event(const SDL_Event& ev)
 {
-  items[active_item]->event(ev);
-  switch (ev.type) {
+  m_items[m_active_item]->event(ev);
+  switch (ev.type)
+  {
     case SDL_KEYDOWN:
     case SDL_TEXTINPUT:
       if (((ev.type == SDL_KEYDOWN && ev.key.keysym.sym == SDLK_BACKSPACE) ||
-         ev.type == SDL_TEXTINPUT) && items[active_item]->changes_width())
+         ev.type == SDL_TEXTINPUT) && m_items[m_active_item]->changes_width())
       {
         // Changed item value? Let's recalculate width:
         calculate_width();
@@ -618,10 +659,10 @@ Menu::event(const SDL_Event& ev)
     {
       Vector mouse_pos = VideoSystem::current()->get_viewport().to_logical(ev.motion.x, ev.motion.y);
 
-      if (mouse_pos.x > pos.x - get_width() / 2.0f &&
-          mouse_pos.x < pos.x + get_width() / 2.0f &&
-          mouse_pos.y > pos.y - get_height() / 2.0f &&
-          mouse_pos.y < pos.y + get_height() / 2.0f)
+      if (mouse_pos.x > m_pos.x - get_width() / 2.0f &&
+          mouse_pos.x < m_pos.x + get_width() / 2.0f &&
+          mouse_pos.y > m_pos.y - get_height() / 2.0f &&
+          mouse_pos.y < m_pos.y + get_height() / 2.0f)
       {
         process_action(MenuAction::HIT);
       }
@@ -634,17 +675,17 @@ Menu::event(const SDL_Event& ev)
       float x = mouse_pos.x;
       float y = mouse_pos.y;
 
-      if (x > pos.x - get_width()/2 &&
-         x < pos.x + get_width()/2 &&
-         y > pos.y - get_height()/2 &&
-         y < pos.y + get_height()/2)
+      if (x > m_pos.x - get_width()/2 &&
+         x < m_pos.x + get_width()/2 &&
+         y > m_pos.y - get_height()/2 &&
+         y < m_pos.y + get_height()/2)
       {
         int new_active_item
-          = static_cast<int> ((y - (pos.y - get_height()/2)) / 24);
+          = static_cast<int> ((y - (m_pos.y - get_height()/2)) / 24);
 
         /* only change the mouse focus to a selectable item */
-        if (!items[new_active_item]->skippable())
-          active_item = new_active_item;
+        if (!m_items[new_active_item]->skippable())
+          m_active_item = new_active_item;
 
         if (MouseCursor::current())
           MouseCursor::current()->set_state(MouseCursorState::LINK);
@@ -665,16 +706,17 @@ Menu::event(const SDL_Event& ev)
 void
 Menu::set_active_item(int id)
 {
-  for (size_t i = 0; i < items.size(); ++i) {
-    if (items[i]->get_id() == id) {
-      active_item = static_cast<int>(i);
+  for (size_t i = 0; i < m_items.size(); ++i) {
+    if (m_items[i]->get_id() == id) {
+      m_active_item = static_cast<int>(i);
       break;
     }
   }
 }
 
 bool
-Menu::is_sensitive() const {
+Menu::is_sensitive() const
+{
   return false;
 }
 
