@@ -22,7 +22,8 @@
 Decal::Decal(const ReaderMapping& reader) :
   MovingSprite(reader, "images/decal/explanations/billboard-bigtux.png", LAYER_OBJECTS, COLGROUP_DISABLED),
   default_action("default"),
-  solid()
+  solid(),
+  flip(NO_FLIP)
 {
   m_layer = reader_get_layer(reader, LAYER_OBJECTS);
 
@@ -51,4 +52,11 @@ Decal::~Decal()
 {
 }
 
+void
+Decal::draw(DrawingContext& context)
+{
+  m_sprite->draw(context.color(), get_pos(), m_layer, flip);
+}
+
+
 /* EOF */
