@@ -19,7 +19,7 @@
 #include "supertux/sector.hpp"
 
 Electrifier::Electrifier(TileChangeMap replacements, float seconds) :
-  change_map(replacements),
+  change_map(std::move(replacements)),
   duration()
 {
   duration.start(seconds);
@@ -32,7 +32,10 @@ Electrifier::Electrifier(uint32_t oldtile, uint32_t newtile, float seconds) :
   change_map({{oldtile, newtile}}),
   duration()
 {
-  Electrifier(change_map, seconds);
+  duration.start(seconds);
+  for (auto& tile : change_map) {
+    Sector::get().change_solid_tiles(tile.first, tile.second);
+  }
 }
 
 void
