@@ -379,7 +379,7 @@ Player::update(float dt_sec)
 
       // if controls are currently deactivated, we take care of standing up ourselves
       if (m_deactivated)
-        do_standup();
+        do_standup(false);
     }
     if (m_player_status.bonus == AIR_BONUS)
       m_ability_time = static_cast<float>(m_player_status.max_air_time) * GLIDE_TIME_PER_FLOWER;
@@ -434,8 +434,8 @@ Player::update(float dt_sec)
     if (m_sprite->animation_done()) m_growing = false;
   }
 
-  // when climbing animate only while moving
-  if (m_climbing){
+  // when climbing animate only while moving or growing
+  if (m_climbing && !m_growing){
     if ((m_physic.get_velocity_x()==0)&&(m_physic.get_velocity_y()==0))
       m_sprite->stop_animation();
     else
@@ -586,7 +586,7 @@ Player::do_cheer()
 {
   do_duck();
   do_backflip();
-  do_standup();
+  do_standup(false);
 }
 
 void
@@ -607,13 +607,11 @@ Player::do_duck() {
     m_duck = true;
     m_growing = false;
     m_unduck_hurt_timer.stop();
-  } else {
-    // FIXME: what now?
   }
 }
 
 void
-Player::do_standup() {
+Player::do_standup(bool force_standup) {
   if (!m_duck)
     return;
   if (!is_big())
@@ -626,7 +624,7 @@ Player::do_standup() {
   if (adjust_height(BIG_TUX_HEIGHT)) {
     m_duck = false;
     m_unduck_hurt_timer.stop();
-  } else {
+  } else if (force_standup) {
     // if timer is not already running, start it.
     if (m_unduck_hurt_timer.get_period() == 0) {
       m_unduck_hurt_timer.start(UNDUCK_HURT_TIME);
@@ -870,7 +868,7 @@ Player::handle_input()
   if (m_controller->hold(Control::DOWN) && !m_stone) {
     do_duck();
   } else {
-    do_standup();
+    do_standup(false);
   }
 
   /* grabbing */
@@ -1072,9 +1070,11 @@ Player::set_bonus(BonusType type, bool animate)
     }
     if (animate) {
       m_growing = true;
-      m_sprite->set_action((m_dir == Direction::LEFT)?"grow-left":"grow-right", 1);
+      if (m_climbing)
+        m_sprite->set_action((m_dir == Direction::LEFT)?"grow-ladder-left":"grow-ladder-right", 1);
+      else
+        m_sprite->set_action((m_dir == Direction::LEFT)?"grow-left":"grow-right", 1);
     }
-    if (m_climbing) stop_climbing(*m_climbing);
   }
 
   if (type == NO_BONUS) {
@@ -1117,7 +1117,6 @@ Player::set_bonus(BonusType type, bool animate)
       Sector::get().add<SpriteParticle>("images/objects/particles/" + particle_name + ".sprite",
                                              action, ppos, ANCHOR_TOP, pspeed, paccel, LAYER_OBJECTS - 1);
     }
-    if (m_climbing) stop_climbing(*m_climbing);
 
     m_player_status.max_fire_bullets = 0;
     m_player_status.max_ice_bullets = 0;
@@ -1204,7 +1203,12 @@ Player::draw(DrawingContext& context)
     m_sprite->set_action("gameover");
   }
   else if (m_growing) {
-    m_sprite->set_action_continued("grow"+sa_postfix);
+    if (m_climbing) {
+      m_sprite->set_action_continued("grow-ladder"+sa_postfix);
+    }
+    else {
+      m_sprite->set_action_continued("grow"+sa_postfix);
+    }
     // while growing, do not change action
     // do_duck() will take care of cancelling growing manually
     // update() will take care of cancelling when growing completed
@@ -1214,6 +1218,10 @@ Player::draw(DrawingContext& context)
   }
   else if (m_climbing) {
     m_sprite->set_action(sa_prefix+"-climbing"+sa_postfix);
+
+    // Avoid flickering briefly after growing on ladder
+    if ((m_physic.get_velocity_x()==0)&&(m_physic.get_velocity_y()==0))
+      m_sprite->stop_animation();
   }
   else if (m_backflipping) {
     m_sprite->set_action(sa_prefix+"-backflip"+sa_postfix);
@@ -1668,7 +1676,7 @@ Player::start_climbing(Climbable& climbable)
   m_physic.set_acceleration(0, 0);
   if (m_backflipping) {
     stop_backflipping();
-    do_standup();
+    do_standup(true);
   }
 }
 
@@ -1688,9 +1696,12 @@ Player::stop_climbing(Climbable& /*climbable*/)
   m_physic.set_velocity(0, 0);
   m_physic.set_acceleration(0, 0);
 
-  if ((m_controller->hold(Control::JUMP)) || (m_controller->hold(Control::UP))) {
+  if (m_controller->hold(Control::JUMP)) {
+    m_on_ground_flag = true;
+    do_jump(m_player_status.bonus == BonusType::AIR_BONUS ? -540 : -480);
+  }
+  else if (m_controller->hold(Control::UP)) {
     m_on_ground_flag = true;
-    // TODO: This won't help. Why?
     do_jump(-300);
   }
 }
