@@ -27,7 +27,8 @@ class SkullTile final : public MovingSprite
 public:
   SkullTile(const ReaderMapping& mapping);
 
-  virtual std::string get_class() const override { return "skulltile"; }
+  virtual std::string get_class() const override { return "skull_tile"; }
+  virtual std::string get_display_name() const override { return _("Skull Tile"); }
 
   virtual HitResponse collision(GameObject& other, const CollisionHit& hit) override;
   virtual void update(float dt_sec) override;
