@@ -30,6 +30,7 @@
 #include "video/drawing_context.hpp"
 #include "video/layer.hpp"
 #include "video/surface.hpp"
+#include "worldmap/worldmap.hpp"
 
 TileMap::TileMap(const TileSet *new_tileset) :
   ExposedObject<TileMap, scripting::TileMap>(this),
@@ -625,12 +626,20 @@ TileMap::move_by(const Vector& shift)
 void
 TileMap::update_effective_solid()
 {
+  bool old = m_effective_solid;
   if (!m_real_solid)
     m_effective_solid = false;
   else if (m_effective_solid && (m_current_alpha < 0.25f))
     m_effective_solid = false;
   else if (!m_effective_solid && (m_current_alpha >= 0.75f))
     m_effective_solid = true;
+  
+  if(Sector::current() != nullptr && old != m_effective_solid)  
+  {
+      Sector::get().update_solid(this);  
+  } else if(worldmap::WorldMap::current() != nullptr && old != m_effective_solid) {
+      worldmap::WorldMap::current()->update_solid(this);
+  }   
 }
 
 void
