@@ -29,6 +29,7 @@
 #include "supertux/game_session.hpp"
 #include "supertux/gameconfig.hpp"
 #include "supertux/globals.hpp"
+#include "supertux/level.hpp"
 #include "supertux/menu/menu_storage.hpp"
 #include "supertux/resources.hpp"
 #include "supertux/screen_fade.hpp"
@@ -193,7 +194,7 @@ void
 ScreenManager::draw_fps(DrawingContext& context, FPS_Stats& fps_statistics)
 {
   // The fonts are not monospace, so the numbers need to be drawn separately
-  Vector pos(static_cast<float>(context.get_width()) - BORDER_X, BORDER_Y + 20);
+  Vector pos(static_cast<float>(context.get_width()) - BORDER_X, BORDER_Y + 50);
   context.color().draw_text(Resources::small_font, "FPS  min / avg / max",
     pos, ALIGN_RIGHT, LAYER_HUD);
   static const float w2 = Resources::small_font->get_text_width("999.9 /");
@@ -256,7 +257,7 @@ ScreenManager::draw(Compositor& compositor, FPS_Stats& fps_statistics)
   if (g_config->show_fps)
     draw_fps(context, fps_statistics);
 
-  if (g_debug.show_controller) {
+  if (g_config->show_controller) {
     m_controller_hud->draw(context);
   }
 
@@ -326,7 +327,7 @@ ScreenManager::process_events()
           case SDL_WINDOWEVENT_FOCUS_LOST:
             if (g_config->pause_on_focusloss)
             {
-              if (session != nullptr && session->is_active())
+              if (session != nullptr && session->is_active() && !Level::current()->m_suppress_pause_menu)
               {
                 session->toggle_pause();
               }
